@@ -33,7 +33,7 @@ from openstack_dashboard.api import base
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-MANILA_VERSION = "2.22"  # requires manilaclient 1.12.0 or newer
+MANILA_VERSION = "2.32"  # requires manilaclient 1.13.0 or newer
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -139,14 +139,15 @@ def share_manage(request, service_host, protocol, export_path,
 
 
 def migration_start(request, share, dest_host, force_host_assisted_migration,
-                    writable, preserve_metadata, nondisruptive,
-                    new_share_network_id, new_share_type_id):
+                    writable, preserve_metadata, preserve_snapshots,
+                    nondisruptive, new_share_network_id, new_share_type_id):
     return manilaclient(request).shares.migration_start(
         share,
         host=dest_host,
         force_host_assisted_migration=force_host_assisted_migration,
         writable=writable,
         preserve_metadata=preserve_metadata,
+        preserve_snapshots=preserve_snapshots,
         nondisruptive=nondisruptive,
         new_share_network_id=new_share_network_id,
         new_share_type_id=new_share_type_id
@@ -207,6 +208,29 @@ def share_snapshot_delete(request, snapshot_id):
     return manilaclient(request).share_snapshots.delete(snapshot_id)
 
 
+def share_snapshot_allow(request, snapshot_id, access_type, access_to):
+    return manilaclient(request).share_snapshots.allow(
+        snapshot_id, access_type, access_to)
+
+
+def share_snapshot_deny(request, snapshot_id, rule_id):
+    return manilaclient(request).share_snapshots.deny(snapshot_id, rule_id)
+
+
+def share_snapshot_rules_list(request, snapshot_id):
+    return manilaclient(request).share_snapshots.access_list(snapshot_id)
+
+
+def share_snap_export_location_list(request, snapshot):
+    return manilaclient(request).share_snapshot_export_locations.list(
+        snapshot=snapshot)
+
+
+def share_snap_instance_export_location_list(request, snapshot_instance):
+    return manilaclient(request).share_snapshot_export_locations.list(
+        snapshot_instance=snapshot_instance)
+
+
 def share_server_list(request, search_opts=None):
     return manilaclient(request).share_servers.list(search_opts=search_opts)
 
@@ -225,10 +249,10 @@ def share_network_list(request, detailed=False, search_opts=None):
 
 
 def share_network_create(request, neutron_net_id=None, neutron_subnet_id=None,
-                         nova_net_id=None, name=None, description=None):
+                         name=None, description=None):
     return manilaclient(request).share_networks.create(
         neutron_net_id=neutron_net_id, neutron_subnet_id=neutron_subnet_id,
-        nova_net_id=nova_net_id, name=name, description=description)
+        name=name, description=description)
 
 
 def share_network_get(request, share_net_id):
@@ -428,6 +452,10 @@ def availability_zone_list(request):
     return manilaclient(request).availability_zones.list()
 
 
+def pool_list(request, detailed=False):
+    return manilaclient(request).pools.list(detailed=detailed)
+
+
 @memoized
 def is_replication_enabled():
     manila_config = getattr(settings, 'OPENSTACK_MANILA_FEATURES', {})
