@@ -15,7 +15,6 @@
 from django.core.urlresolvers import NoReverseMatch  # noqa
 from django.core.urlresolvers import reverse
 from django.template.defaultfilters import title  # noqa
-from django.utils.safestring import mark_safe
 from django.utils.translation import string_concat, ugettext_lazy  # noqa
 from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
@@ -149,8 +148,7 @@ class UpdateRow(tables.Row):
             share.share_network = share_net.name or share_net.id
         else:
             share.share_network = None
-        meta_str = utils.metadata_to_str(share.metadata)
-        share.metadata = mark_safe(meta_str)
+        share.metadata = utils.metadata_to_str(share.metadata)
 
         return share
 
@@ -164,6 +162,7 @@ class SharesTableBase(tables.DataTable):
         ("available", True), ("AVAILABLE", True),
         ("creating", None), ("CREATING", None),
         ("deleting", None), ("DELETING", None),
+        ("migrating", None), ("migrating_to", None),
         ("error", False), ("ERROR", False),
         ("error_deleting", False), ("ERROR_DELETING", False),
         ("MANAGE_ERROR", False),
@@ -177,6 +176,9 @@ class SharesTableBase(tables.DataTable):
         ("CREATING", pgettext_lazy("Current status of share", u"Creating")),
         ("deleting", pgettext_lazy("Current status of share", u"Deleting")),
         ("DELETING", pgettext_lazy("Current status of share", u"Deleting")),
+        ("migrating", pgettext_lazy("Current status of share", u"Migrating")),
+        ("migrating_to", pgettext_lazy("Current status of share",
+                                       u"Migrating to")),
         ("error", pgettext_lazy("Current status of share", u"Error")),
         ("ERROR", pgettext_lazy("Current status of share", u"Error")),
         ("error_deleting", pgettext_lazy("Current status of share",
@@ -190,9 +192,9 @@ class SharesTableBase(tables.DataTable):
         ("extending_error", pgettext_lazy("Current status of share",
                                           u"Extending Error")),
     )
-    name = tables.Column("name",
-                         verbose_name=_("Name"),
-                         link="horizon:project:shares:detail")
+    name = tables.WrappingColumn(
+        "name", verbose_name=_("Name"),
+        link="horizon:project:shares:detail")
     description = tables.Column("description",
                                 verbose_name=_("Description"),
                                 truncate=40)
@@ -216,10 +218,21 @@ class ManageRules(tables.LinkAction):
     name = "manage_rules"
     verbose_name = _("Manage Rules")
     url = "horizon:project:shares:manage_rules"
-    classes = ("btn-edit", )
+    classes = ("btn-edit",)
     policy_rules = (("share", "share:access_get_all"),)
 
 
+class ManageReplicas(tables.LinkAction):
+    name = "manage_replicas"
+    verbose_name = _("Manage Replicas")
+    url = "horizon:project:shares:manage_replicas"
+    classes = ("btn-edit",)
+    policy_rules = (("share", "share:replica_get_all"),)
+
+    def allowed(self, request, *args, **kwargs):
+        return manila.is_replication_enabled()
+
+
 class AddRule(tables.LinkAction):
     name = "rule_add"
     verbose_name = _("Add rule")
@@ -268,6 +281,7 @@ class RulesTable(tables.DataTable):
     access_level = tables.Column(
         "access_level", verbose_name=_("Access Level"))
     status = tables.Column("state", verbose_name=_("Status"))
+    access_key = tables.Column("access_key", verbose_name=_("Access Key"))
 
     def get_object_display(self, obj):
         return obj.id
@@ -290,9 +304,9 @@ def get_share_network(share):
 
 
 class SharesTable(SharesTableBase):
-    name = tables.Column("name",
-                         verbose_name=_("Name"),
-                         link="horizon:project:shares:detail")
+    name = tables.WrappingColumn(
+        "name", verbose_name=_("Name"),
+        link="horizon:project:shares:detail")
     visibility = tables.Column(
         "is_public", verbose_name=_("Visibility"),
         help_text=("Whether this share visible to all tenants (public) or "
@@ -318,5 +332,6 @@ class SharesTable(SharesTableBase):
             ExtendShare,
             snapshot_tables.CreateSnapshot,
             ManageRules,
+            ManageReplicas,
             EditShareMetadata,
             DeleteShare)
