@@ -19,5 +19,6 @@ OPENSTACK_MANILA_FEATURES = {
     'enable_migration': True,
     'enable_public_share_type_creation': True,
     'enable_public_shares': True,
-    'enabled_share_protocols': ['NFS', 'CIFS', 'GlusterFS', 'HDFS', 'CephFS'],
+    'enabled_share_protocols': ['NFS', 'CIFS', 'GlusterFS', 'HDFS', 'CephFS',
+                                'MapRFS'],
 }
