@@ -13,17 +13,20 @@
 #    under the License.
 
 import ddt
+from django.core.handlers import wsgi
 from django.core.urlresolvers import reverse
 import mock
 import six
 
+from horizon import messages as horizon_messages
 from manila_ui.api import manila as api_manila
+from manila_ui.dashboards.project.shares.shares import forms
+from manila_ui.dashboards import utils
 from manila_ui.tests.dashboards.project.shares import test_data
 from manila_ui.tests import helpers as test
 
 from openstack_dashboard.api import base
 from openstack_dashboard.api import neutron
-from openstack_dashboard.api import nova
 from openstack_dashboard.usage import quotas
 
 SHARE_INDEX_URL = reverse('horizon:project:shares:index')
@@ -47,7 +50,7 @@ class ShareViewTests(test.TestCase):
 
     class FakeAZ(object):
         def __init__(self, name):
-            self.zoneName = name
+            self.name = name
 
     def setUp(self):
         super(ShareViewTests, self).setUp()
@@ -60,7 +63,7 @@ class ShareViewTests(test.TestCase):
         self.mock_object(
             api_manila, "share_get", mock.Mock(return_value=self.share))
 
-    @mock.patch.object(nova, 'availability_zone_list')
+    @mock.patch.object(api_manila, 'availability_zone_list')
     def test_create_share(self, az_list):
         url = reverse('horizon:project:shares:create')
         share = test_data.share
@@ -102,7 +105,7 @@ class ShareViewTests(test.TestCase):
         api_manila.share_network_list.assert_called_once_with(mock.ANY)
         api_manila.share_type_list.assert_called_once_with(mock.ANY)
 
-    @mock.patch.object(nova, 'availability_zone_list')
+    @mock.patch.object(api_manila, 'availability_zone_list')
     def test_create_share_from_snapshot(self, mock_az_list):
         share = test_data.share
         share_net = test_data.active_share_network
@@ -180,8 +183,6 @@ class ShareViewTests(test.TestCase):
         rules = [test_data.ip_rule, test_data.user_rule, test_data.cephx_rule]
         export_locations = test_data.export_locations
         url = reverse('horizon:project:shares:detail', args=[self.share.id])
-        self.mock_object(
-            neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         self.mock_object(
             api_manila, "share_network_get", mock.Mock(return_value=share_net))
         self.mock_object(
@@ -214,13 +215,25 @@ class ShareViewTests(test.TestCase):
             2, 200)
         for rule in rules:
             self.assertContains(res, "<dt>%s</dt>" % rule.access_type, 1, 200)
-            self.assertContains(res, "<dd>%s</dd>" % rule.access_to, 1, 200)
+            self.assertContains(
+                res, "<div><b>Access to: </b>%s</div>" % rule.access_to,
+                1, 200)
+            if 'cephx' == rule.access_type:
+                self.assertContains(
+                    res, "<div><b>Access Key: </b>%s</div>" % rule.access_key,
+                    1, 200)
+        self.assertContains(
+            res, "<div><b>Access Key: </b></div>",
+            len(rules) - sum(r.access_type == 'cephx' for r in rules), 200)
+        self.assertContains(
+            res, "<div><b>Access Level: </b>rw</div>", len(rules), 200)
+        self.assertContains(
+            res, "<div><b>Status: </b>active</div>", len(rules), 200)
         self.assertNoMessages()
         api_manila.share_rules_list.assert_called_once_with(
             mock.ANY, self.share.id)
         api_manila.share_export_location_list.assert_called_once_with(
             mock.ANY, self.share.id)
-        self.assertEqual(3, neutron.is_service_enabled.call_count)
 
     def test_update_share_get(self):
         share = test_data.share
@@ -257,8 +270,6 @@ class ShareViewTests(test.TestCase):
         rules = [test_data.ip_rule, test_data.user_rule, test_data.cephx_rule]
         self.mock_object(
             api_manila, "share_rules_list", mock.Mock(return_value=rules))
-        self.mock_object(
-            neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         url = reverse(
             'horizon:project:shares:manage_rules', args=[self.share.id])
 
@@ -268,7 +279,6 @@ class ShareViewTests(test.TestCase):
         self.assertTemplateUsed(res, 'project/shares/shares/manage_rules.html')
         api_manila.share_rules_list.assert_called_once_with(
             mock.ANY, self.share.id)
-        self.assertEqual(3, neutron.is_service_enabled.call_count)
 
     def test_create_rule_get(self):
         url = reverse('horizon:project:shares:rule_add', args=[self.share.id])
@@ -342,8 +352,6 @@ class ShareViewTests(test.TestCase):
             'totalShareGigabytesUsed': self.share.size,
         }
         url = reverse('horizon:project:shares:extend', args=[self.share.id])
-        self.mock_object(
-            neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         self.mock_object(api_manila, "share_extend")
         self.mock_object(
             quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
@@ -355,7 +363,6 @@ class ShareViewTests(test.TestCase):
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
         self.assertFalse(api_manila.share_extend.called)
         quotas.tenant_limit_usages.assert_called_once_with(mock.ANY)
-        self.assertEqual(3, neutron.is_service_enabled.call_count)
 
     def test_extend_share_get_with_api_exception(self):
         usage_limit = {
@@ -412,8 +419,6 @@ class ShareViewTests(test.TestCase):
             'totalShareGigabytesUsed': self.share.size,
         }
         url = reverse('horizon:project:shares:extend', args=[self.share.id])
-        self.mock_object(
-            neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         self.mock_object(api_manila, "share_extend")
         self.mock_object(
             quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
@@ -425,7 +430,6 @@ class ShareViewTests(test.TestCase):
         self.assertFalse(api_manila.share_extend.called)
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
         quotas.tenant_limit_usages.assert_called_with(mock.ANY)
-        self.assertEqual(3, neutron.is_service_enabled.call_count)
 
     def test_extend_share_post_with_api_exception(self):
         self.share.size = 5
@@ -489,3 +493,129 @@ class ShareViewTests(test.TestCase):
         api_manila.share_set_metadata.assert_called_once_with(
             mock.ANY, share, form_data['metadata'])
         self.assertRedirectsNoFollow(res, SHARE_INDEX_URL)
+
+
+@ddt.ddt
+class ShareViewFormTests(ShareViewTests, test.APITestCase):
+
+    def setUp(self):
+        super(ShareViewFormTests, self).setUp()
+        FAKE_ENVIRON = {'REQUEST_METHOD': 'GET', 'wsgi.input': 'fake_input'}
+        self.request = wsgi.WSGIRequest(FAKE_ENVIRON)
+        self.mock_object(
+            horizon_messages, "success",
+            mock.Mock())
+
+    @ddt.data((True, True), (True, False), (False, False))
+    @ddt.unpack
+    def test_enable_public_share_creation(self,
+                                          enable_public_shares,
+                                          is_public):
+        def _get_form(**kwargs):
+            return forms.CreateForm(self.request, **kwargs)
+
+        self.mock_object(
+            api_manila, "share_create", mock.Mock(return_value=self.share))
+        self.mock_object(
+            api_manila, "share_snapshot_list", mock.Mock(return_value=[]))
+        self.mock_object(
+            api_manila, "share_network_list",
+            mock.Mock(return_value=[test_data.active_share_network]))
+        self.mock_object(
+            api_manila, "share_type_list",
+            mock.Mock(return_value=[self.fake_share_type, ]))
+        self.mock_object(
+            api_manila, "availability_zone_list",
+            mock.Mock(return_value=[self.FakeAZ('fake_az'), ]))
+
+        data = {
+            'name': u'new_share',
+            'description': u'This is test share',
+            'method': u'CreateForm',
+            'share_network': test_data.active_share_network.id,
+            'size': 1,
+            'share_proto': u'NFS',
+            'share_type': 'fake',
+            'share-network-choices-fake': test_data.active_share_network.id,
+            'availability_zone': 'fake_az',
+            'metadata': 'key=value',
+            'snapshot_id': None,
+        }
+        if enable_public_shares:
+            data.update({'is_public': is_public})
+
+        with self.settings(OPENSTACK_MANILA_FEATURES={
+            'enable_public_shares': enable_public_shares}):
+                form = _get_form()
+                result = form.handle(self.request, data)
+                self.assertTrue(result)
+                self.assertEqual(
+                    enable_public_shares,
+                    form.enable_public_shares)
+                if enable_public_shares:
+                    self.assertIn("is_public", form.fields)
+                    self.assertTrue(form.fields["is_public"])
+                else:
+                    self.assertNotIn("is_public", form.fields)
+                api_manila.share_create.assert_called_once_with(
+                    self.request,
+                    availability_zone=data['availability_zone'],
+                    description=data['description'],
+                    is_public=is_public,
+                    metadata=utils.parse_str_meta(data['metadata'])[0],
+                    name=data['name'],
+                    proto=data['share_proto'],
+                    share_network=test_data.active_share_network.id,
+                    share_type=data['share_type'],
+                    size=data['size'],
+                    snapshot_id=data['snapshot_id'],
+                )
+                horizon_messages.success.assert_called_once_with(
+                    self.request, mock.ANY)
+
+    @ddt.data((True, True), (True, False), (False, False))
+    @ddt.unpack
+    def test_enable_public_share_update(self,
+                                        enable_public_shares,
+                                        is_public):
+        def _get_form(initial):
+            kwargs = {
+                'prefix': None,
+                'initial': initial,
+            }
+            return forms.UpdateForm(self.request, **kwargs)
+
+        initial = {'share_id': 'fake_share_id'}
+
+        self.mock_object(
+            api_manila, "share_update", mock.Mock(return_value=self.share))
+
+        data = {
+            'name': u'old_share',
+            'description': u'This is test share',
+        }
+        if enable_public_shares:
+            data.update({'is_public': is_public})
+
+        with self.settings(OPENSTACK_MANILA_FEATURES={
+            'enable_public_shares': enable_public_shares}):
+                form = _get_form(initial)
+                result = form.handle(self.request, data)
+                self.assertTrue(result)
+                self.assertEqual(
+                    enable_public_shares,
+                    form.enable_public_shares)
+                if enable_public_shares:
+                    self.assertIn("is_public", form.fields)
+                    self.assertTrue(form.fields["is_public"])
+                else:
+                    self.assertNotIn("is_public", form.fields)
+                api_manila.share_update.assert_called_once_with(
+                    self.request,
+                    self.share,
+                    data['name'],
+                    data['description'],
+                    is_public=is_public,
+                )
+                horizon_messages.success.assert_called_once_with(
+                    self.request, mock.ANY)
